(chat-completion config messages tools)Non-streaming chat completion against any OpenAI-compatible endpoint — local servers (llama.cpp, vLLM, Ollama, LM Studio) or online providers. Sends a Bearer token only when an API key is configured, and retries transient failures (429/5xx) with linear backoff.
Non-streaming chat completion against any OpenAI-compatible endpoint — local servers (llama.cpp, vLLM, Ollama, LM Studio) or online providers. Sends a Bearer token only when an API key is configured, and retries transient failures (429/5xx) with linear backoff.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |