ajent.tools


get-toolsclj

(get-tools)

Returns a vector of OpenAI function schemas for the LLM.

Returns a vector of OpenAI function schemas for the LLM.
sourceraw docstring

get-tools-by-namesclj

(get-tools-by-names tool-names)

Returns a vector of tool schemas filtered dynamically by tool names.

Returns a vector of tool schemas filtered dynamically by tool names.
sourceraw docstring

handle-tool-callclj

(handle-tool-call tool-name args-map)

Dispatches to the matching tool server (REST or MCP). Returns the result as a string.

Dispatches to the matching tool server (REST or MCP). Returns the result as a string.
sourceraw docstring

refresh-registry!clj

(refresh-registry!)
source

cljdoc builds & hosts documentation for Clojure/Script libraries