(get-tools)Returns a vector of OpenAI function schemas for the LLM.
Returns a vector of OpenAI function schemas for the LLM.
(get-tools-by-names tool-names)Returns a vector of tool schemas filtered dynamically by tool names.
Returns a vector of tool schemas filtered dynamically by tool names.
(handle-tool-call tool-name args-map)Dispatches to the matching tool server (REST or MCP). Returns the result as a string.
Dispatches to the matching tool server (REST or MCP). Returns the result as a string.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |